.. _sec-atmosphere-homogeneous:

Homogeneous atmospheres
=======================

The homogeneous atmosphere is a homogeneous participating medium characterised
by spatially invariant extinction coefficient, albedo and phase function.
The :class:`~eradiate.scenes.atmosphere.HomogeneousAtmosphere` class allows
to create homogeneous atmosphere objects with user-controlled vertical extent, 
absorption and scattering coefficients and phase function.
